@@ -37,16 +37,13 @@
 
 #include <QDebug>
 #include <QStandardPaths>
-#include <QtTest/QTest>
+#include <QTest>
 
 using namespace KDevelop;
 
 QTEST_MAIN(Python::PyCompletionTest)
 
 Q_DECLARE_METATYPE(QList<Python::RangeInString>)
-#if KTEXTEDITOR_VERSION < QT_VERSION_CHECK(5, 10, 0)
-Q_DECLARE_METATYPE(KTextEditor::Range)
-#endif
 
 static int testId = 0;
 static QString basepath = "/tmp/__kdevpythoncompletiontest.dir/";
