@@ -20,6 +20,7 @@
 
 #include "correctionfilegenerator.h"
 
+#include <QAction>
 #include <QTemporaryFile>
 
 #include <language/backgroundparser/backgroundparser.h>
@@ -41,6 +42,12 @@
 #include <QStack>
 #include "codegendebug.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#define SkipEmptyParts Qt::SkipEmptyParts
+#else
+#define SkipEmptyParts QString::SkipEmptyParts
+#endif
+
 using namespace KDevelop;
 
 namespace Python {
@@ -164,7 +171,7 @@ void TypeCorrection::accepted()
 
     CorrectionFileGenerator::HintType hintType = dialog->hintType();
 
-    generator.addHint(m_ui->typeText->text(), m_ui->importsText->text().split(',', QString::SkipEmptyParts), decl.data(), hintType);
+    generator.addHint(m_ui->typeText->text(), m_ui->importsText->text().split(',', SkipEmptyParts), decl.data(), hintType);
 
     qCDebug(KDEV_PYTHON_CODEGEN) << "Forcing a reparse on " << decl.data()->topContext()->url();
     ICore::self()->languageController()->backgroundParser()->addDocument(IndexedString(decl.data()->topContext()->url()),
